error_to_string

Function error_to_string 

pub fn error_to_string(err: &(dyn Error + 'static)) -> String
Formats an error and its source chain into a single string, joining each level with : (equivalent to formatting an anyhow error with the alternate {:#} specifier).