pub struct FormatError(/* private fields */);Expand description
An error returned by formatting operations.
This can hold any error, allowing plugins to return their own error types,
while still implementing std::error::Error so that consumers can convert
it into their own error type.
Implementations
Sourceimpl FormatError
impl FormatError
Sourcepub fn new(error: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn new(error: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates a new error from anything that can be turned into a boxed error
(for example a String, &str, or any std::error::Error).
Sourcepub fn downcast_ref<E: Error + 'static>(&self) -> Option<&E>
pub fn downcast_ref<E: Error + 'static>(&self) -> Option<&E>
Attempts to downcast the underlying error to a concrete type
(ex. to check for a CriticalFormatError).