[−][src]Struct dprint_core::Info
Can be used to get information at a certain location being printed. These can be resolved by providing the info object to a condition context's getResolvedInfo method.
Fields
name: &'static strName for debugging purposes.
Methods
impl Info[src]
pub fn new(name: &'static str) -> Info[src]
pub fn into_clone<TString, TCondition>(
&self
) -> PrintItem<TString, Info, TCondition> where
TString: StringRef,
TCondition: ConditionRef<TString, Info, TCondition>, [src]
&self
) -> PrintItem<TString, Info, TCondition> where
TString: StringRef,
TCondition: ConditionRef<TString, Info, TCondition>,