ConditionResolverContext

Struct ConditionResolverContext 

pub struct ConditionResolverContext<'a, 'b> {
    pub writer_info: WriterInfo,
    /* private fields */
}
Context used when resolving a condition.

Fields

writer_info: WriterInfo

Gets the writer info at the condition’s location.

Implementations

Source

impl<'a, 'b> ConditionResolverContext<'a, 'b>

pub fn resolved_condition( &mut self, condition_reference: &ConditionReference, ) -> Option<bool>

Gets if a condition was true, false, or returns None when not yet resolved. A condition reference can be retrieved by calling the create_reference() on a condition.

pub fn resolved_line_and_column( &mut self, line_and_column: LineAndColumn, ) -> Option<(u32, u32)>

Gets a resolved line and column.

pub fn resolved_line_number(&mut self, line_number: LineNumber) -> Option<u32>

Gets the line number or returns None when not yet resolved.

pub fn resolved_column_number( &mut self, column_number: ColumnNumber, ) -> Option<u32>

Gets the column number or returns None when not yet resolved.

pub fn resolved_is_start_of_line( &mut self, is_start_of_line: IsStartOfLine, ) -> Option<bool>

Gets if the info is at the start of the line or returns None when not yet resolved.

pub fn resolved_indent_level(&mut self, indent_level: IndentLevel) -> Option<u8>

Gets if the indent level at this info or returns None when not yet resolved.

pub fn resolved_line_start_column_number( &mut self, line_start_column_number: LineStartColumnNumber, ) -> Option<u32>

Gets the column number at the start of the line this info appears or returns None when not yet resolved.

pub fn resolved_line_start_indent_level( &mut self, line_start_indent_level: LineStartIndentLevel, ) -> Option<u8>

Gets the indent level at the start of the line this info appears or returns None when not yet resolved.

pub fn clear_line_and_column(&mut self, lc: LineAndColumn)

Clears the line and column from being stored.

pub fn clear_info(&mut self, info: impl Into<Info>)

Clears the info from being stored.

pub fn shift_line_number(&mut self, info: LineNumber, delta: isize)

Moves an already resolved line number by delta lines.

Use this instead of clearing when the text the line number refers to has only moved up or down the page, so that it stays correct relative to everything around it.

pub fn is_forcing_no_newlines(&self) -> bool

Gets if the printer is currently forcing no newlines.